.. _api:

API Reference
=============

Classifiers
-----------

.. automodule:: formasaurus.classifiers
    :members:

Field Type Detection
--------------------

.. automodule:: formasaurus.fieldtype_model
    :members:

Form Type Detection
-------------------

.. automodule:: formasaurus.formtype_model
    :members:

.. automodule:: formasaurus.formtype_features
    :members:

Working with Training Data
--------------------------

.. automodule:: formasaurus.storage
    :members:

.. automodule:: formasaurus.annotation
    :members:

HTML Processing Utilities
-------------------------

.. automodule:: formasaurus.html
    :members:

.. automodule:: formasaurus.formhash
    :members:

Other Utilities
---------------

.. automodule:: formasaurus.utils
    :members:

.. automodule:: formasaurus.text
    :members:

IPython Annotation Widgets
--------------------------

.. automodule:: formasaurus.widgets
    :members:


